@@ -707,12 +707,9 @@ class ChangesProcessor(Object):
         q = q.filter(model.Customer.id == row['F1148'])
         customer = q.first()
         if customer:
-            while customer.emails:
-                customer.emails.pop()
-            while customer.phones:
-                customer.phones.pop()
-            while customer.groups:
-                customer.groups.pop()
+            customer.emails = []
+            customer.phones = []
+            customer.groups = []
         else:
             person = model.Person()
             person.first_name = row['F1149']
